@@ -35,6 +35,14 @@ namespace Hipo
 	{
 		private Gtk.ListStore store;
 		
+		public enum Column {
+			Artist,
+			Album,
+			Title,
+			Genre,
+			Id
+		}
+		
 		public TracksView ()
 		{
 			store = new Gtk.ListStore (typeof (string), typeof (string),
@@ -58,10 +66,10 @@ namespace Hipo
 		
 		public void UpdateStore (Track track, TreeIter iter)
 		{
-			store.SetValue (iter, 0, track.Artist);
-			store.SetValue (iter, 1, track.Album);
-			store.SetValue (iter, 2, track.Title);
-			store.SetValue (iter, 3, track.Genre);
+			store.SetValue (iter, (int)Column.Artist, track.Artist);
+			store.SetValue (iter, (int)Column.Album, track.Album);
+			store.SetValue (iter, (int)Column.Title, track.Title);
+			store.SetValue (iter, (int)Column.Genre, track.Genre);
 		}
 		
 		public bool AddTrack (TrackDatabase db, string path)
@@ -110,6 +118,9 @@ namespace Hipo
 
 		public bool AddFolder (TrackDatabase db, string[] dirs)
 		{
+			// returns true if at least one track has been added
+			bool trackAdded = false;
+			
 			foreach (string path in dirs)
 			{
 				if (path == null)
@@ -120,16 +131,17 @@ namespace Hipo
 				UnixDirectoryInfo info = new UnixDirectoryInfo (uri.LocalPath);
 				foreach (UnixFileSystemInfo file in info.GetFileSystemEntries ())
 				{
+					// |= gives true as soon as one of the arguments is true
 					if (!file.IsDirectory) {
-						AddTrack (db, file.FullName);
+						trackAdded |= AddTrack (db, file.FullName);
 					} else {
 						string[] tmp = { file.FullName };
-						AddFolder (db, tmp);
+						trackAdded |= AddFolder (db, tmp);
 					}
 				}
 			}
 
-			return true;
+			return trackAdded;
 		}
 
 		public bool RemoveTracks (TrackDatabase db, long tracksId)
